==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/passkit/PKPaymentButtonType.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.passkit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.addressbook.*;
import org.robovm.apple.contacts.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 8.3 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Marshaler(ValuedEnum.AsMachineSizedSIntMarshaler.class)/*</annotations>*/
public enum /*<name>*/PKPaymentButtonType/*</name>*/ implements ValuedEnum {
    /*<values>*/
    Plain(0L),
    Buy(1L),
    /**
     * @since Available in iOS 9.0 and later.
     */
    SetUp(2L);
    /*</values>*/

    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<methods>*//*</methods>*/

    private final long n;

    private /*<name>*/PKPaymentButtonType/*</name>*/(long n) { this.n = n; }
    public long value() { return n; }
    public static /*<name>*/PKPaymentButtonType/*</name>*/ valueOf(long n) {
        for (/*<name>*/PKPaymentButtonType/*</name>*/ v : values()) {
            if (v.n == n) {
                return v;
            }
        }
        throw new IllegalArgumentException("No constant with value " + n + " found in " 
            + /*<name>*/PKPaymentButtonType/*</name>*/.class.getName());
    }
}

==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/passkit/PKPaymentButtonType.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.passkit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.addressbook.*;
import org.robovm.apple.contacts.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coreanimation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 8.3 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Marshaler(ValuedEnum.AsMachineSizedSIntMarshaler.class)/*</annotations>*/
public enum /*<name>*/PKPaymentButtonType/*</name>*/ implements ValuedEnum {
    /*<values>*/
    Plain(0L),
    Buy(1L),
    /**
     * @since Available in iOS 9.0 and later.
     */
    SetUp(2L),
    /**
     * @since Available in iOS 10.0 and later.
     */
    InStore(3L),
    /**
     * @since Available in iOS 10.2 and later.
     */
    Donate(4L),
    /**
     * @since Available in iOS 12.0 and later.
     */
    Checkout(5L),
    /**
     * @since Available in iOS 12.0 and later.
     */
    Book(6L),
    /**
     * @since Available in iOS 12.0 and later.
     */
    Subscribe(7L),
    /**
     * @since Available in iOS 14.0 and later.
     */
    Reload(8L),
    /**
     * @since Available in iOS 14.0 and later.
     */
    AddMoney(9L),
    /**
     * @since Available in iOS 14.0 and later.
     */
    TopUp(10L),
    /**
     * @since Available in iOS 14.0 and later.
     */
    Order(11L),
    /**
     * @since Available in iOS 14.0 and later.
     */
    Rent(12L),
    /**
     * @since Available in iOS 14.0 and later.
     */
    Support(13L),
    /**
     * @since Available in iOS 14.0 and later.
     */
    Contribute(14L),
    /**
     * @since Available in iOS 14.0 and later.
     */
    Tip(15L),
    /**
     * @since Available in iOS 15.0 and later.
     */
    Continue(16L);
    /*</values>*/

    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<methods>*//*</methods>*/

    private final long n;

    private /*<name>*/PKPaymentButtonType/*</name>*/(long n) { this.n = n; }
    public long value() { return n; }
    public static /*<name>*/PKPaymentButtonType/*</name>*/ valueOf(long n) {
        for (/*<name>*/PKPaymentButtonType/*</name>*/ v : values()) {
            if (v.n == n) {
                return v;
            }
        }
        throw new IllegalArgumentException("No constant with value " + n + " found in " 
            + /*<name>*/PKPaymentButtonType/*</name>*/.class.getName());
    }
}
